""" openconfig_types 

This module contains a set of general type definitions that
are used across OpenConfig models. It can be imported by modules
that make use of these types.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class ADDRESSFAMILY(Identity):
    """
    A base identity for all address families
    
    

    """

    _prefix = 'oc-types'
    _revision = '2017-01-13'

    def __init__(self):
        super(ADDRESSFAMILY, self).__init__("http://openconfig.net/yang/openconfig-types", "openconfig-types", "openconfig-types:ADDRESS_FAMILY")


class IPV4(Identity):
    """
    The IPv4 address family
    
    

    """

    _prefix = 'oc-types'
    _revision = '2017-01-13'

    def __init__(self):
        super(IPV4, self).__init__("http://openconfig.net/yang/openconfig-types", "openconfig-types", "openconfig-types:IPV4")


class IPV6(Identity):
    """
    The IPv6 address family
    
    

    """

    _prefix = 'oc-types'
    _revision = '2017-01-13'

    def __init__(self):
        super(IPV6, self).__init__("http://openconfig.net/yang/openconfig-types", "openconfig-types", "openconfig-types:IPV6")


class L2ETHERNET(Identity):
    """
    The 802.3 Ethernet address family
    
    

    """

    _prefix = 'oc-types'
    _revision = '2017-01-13'

    def __init__(self):
        super(L2ETHERNET, self).__init__("http://openconfig.net/yang/openconfig-types", "openconfig-types", "openconfig-types:L2_ETHERNET")


class MPLS(Identity):
    """
    The MPLS address family
    
    

    """

    _prefix = 'oc-types'
    _revision = '2017-01-13'

    def __init__(self):
        super(MPLS, self).__init__("http://openconfig.net/yang/openconfig-types", "openconfig-types", "openconfig-types:MPLS")





""" openconfig_transport_line_common 

This module defines common data elements for OpenConfig data
models for optical transport line system elements, such as
amplifiers and ROADMs (wavelength routers).

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class OPTICALLINEPORTTYPE(Identity):
    """
    Type definition for optical node port types
    
    

    """

    _prefix = 'oc-line-com'
    _revision = '2017-07-08'

    def __init__(self):
        super(OPTICALLINEPORTTYPE, self).__init__("http://openconfig.net/yang/transport-line-common", "openconfig-transport-line-common", "openconfig-transport-line-common:OPTICAL_LINE_PORT_TYPE")


class ADD(Identity):
    """
    Add port, corresponding to a signal injected
    at a wavelength router.
    
    

    """

    _prefix = 'oc-line-com'
    _revision = '2017-07-08'

    def __init__(self):
        super(ADD, self).__init__("http://openconfig.net/yang/transport-line-common", "openconfig-transport-line-common", "openconfig-transport-line-common:ADD")


class DROP(Identity):
    """
    Drop port, corresponding to a signal dropped
    at a wavelength router.
    
    

    """

    _prefix = 'oc-line-com'
    _revision = '2017-07-08'

    def __init__(self):
        super(DROP, self).__init__("http://openconfig.net/yang/transport-line-common", "openconfig-transport-line-common", "openconfig-transport-line-common:DROP")


class EGRESS(Identity):
    """
    Egress port, corresponding to a signal exiting
    a line device such as an amplifier or wavelength
    router.
    
    

    """

    _prefix = 'oc-line-com'
    _revision = '2017-07-08'

    def __init__(self):
        super(EGRESS, self).__init__("http://openconfig.net/yang/transport-line-common", "openconfig-transport-line-common", "openconfig-transport-line-common:EGRESS")


class INGRESS(Identity):
    """
    Ingress port, corresponding to a signal entering
    a line device such as an amplifier or wavelength
    router.
    
    

    """

    _prefix = 'oc-line-com'
    _revision = '2017-07-08'

    def __init__(self):
        super(INGRESS, self).__init__("http://openconfig.net/yang/transport-line-common", "openconfig-transport-line-common", "openconfig-transport-line-common:INGRESS")


class MONITOR(Identity):
    """
    Monitor port, corresponding to a signal used by an optical
    channel monitor. This is used to represent the connection
    that a channel monitor port is connected to. This
    connection may be via physical cable and faceplate ports or
    internal to the device
    
    

    """

    _prefix = 'oc-line-com'
    _revision = '2017-07-08'

    def __init__(self):
        super(MONITOR, self).__init__("http://openconfig.net/yang/transport-line-common", "openconfig-transport-line-common", "openconfig-transport-line-common:MONITOR")





""" openconfig_platform_types 

This module defines data types (e.g., YANG identities)
to support the OpenConfig component inventory model.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class OPENCONFIGHARDWARECOMPONENT(Identity):
    """
    Base identity for hardware related components in a managed
    device.  Derived identities are partially based on contents
    of the IANA Entity MIB.
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(OPENCONFIGHARDWARECOMPONENT, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:OPENCONFIG_HARDWARE_COMPONENT")


class OPENCONFIGSOFTWARECOMPONENT(Identity):
    """
    Base identity for software\-related components in a managed
    device
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(OPENCONFIGSOFTWARECOMPONENT, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:OPENCONFIG_SOFTWARE_COMPONENT")


class BACKPLANE(Identity):
    """
    Backplane component for aggregating traffic, typically
    contained in a chassis component
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(BACKPLANE, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:BACKPLANE")


class CHASSIS(Identity):
    """
    Chassis component, typically with multiple slots / shelves
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(CHASSIS, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:CHASSIS")


class CPU(Identity):
    """
    Processing unit, e.g., a management processor
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(CPU, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:CPU")


class FAN(Identity):
    """
    Cooling fan, or could be some other heat\-reduction component
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(FAN, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:FAN")


class LINECARD(Identity):
    """
    Linecard component, typically inserted into a chassis slot
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(LINECARD, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:LINECARD")


class MODULE(Identity):
    """
    Replaceable hardware module, e.g., a daughtercard
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(MODULE, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:MODULE")


class OPERATINGSYSTEM(Identity):
    """
    Operating system running on a component
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(OPERATINGSYSTEM, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:OPERATING_SYSTEM")


class PORT(Identity):
    """
    Physical port, e.g., for attaching pluggables and networking
    cables
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(PORT, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:PORT")


class POWERSUPPLY(Identity):
    """
    Component that is supplying power to the device
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(POWERSUPPLY, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:POWER_SUPPLY")


class SENSOR(Identity):
    """
    Physical sensor, e.g., a temperature sensor in a chassis
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(SENSOR, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:SENSOR")


class TRANSCEIVER(Identity):
    """
    Pluggable module present in a port
    
    

    """

    _prefix = 'oc-platform-types'
    _revision = '2016-06-06'

    def __init__(self):
        super(TRANSCEIVER, self).__init__("http://openconfig.net/yang/platform-types", "openconfig-platform-types", "openconfig-platform-types:TRANSCEIVER")





""" openconfig_channel_monitor 

This model describes operational state data for an optical
channel monitor (OCM) for optical transport line system
elements such as wavelength routers (ROADMs) and amplifiers.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class ChannelMonitors(Entity):
    """
    Top\-level container for optical channel monitors
    
    .. attribute:: channel_monitor
    
    	List of channel monitors, keyed by channel monitor name
    	**type**\: list of    :py:class:`ChannelMonitor <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor>`
    
    

    """

    _prefix = 'oc-chan-monitor'
    _revision = '2017-07-08'

    def __init__(self):
        super(ChannelMonitors, self).__init__()
        self._top_entity = None

        self.yang_name = "channel-monitors"
        self.yang_parent_name = "openconfig-channel-monitor"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {}
        self._child_list_classes = {"channel-monitor" : ("channel_monitor", ChannelMonitors.ChannelMonitor)}

        self.channel_monitor = YList(self)
        self._segment_path = lambda: "openconfig-channel-monitor:channel-monitors"

    def __setattr__(self, name, value):
        self._perform_setattr(ChannelMonitors, [], name, value)


    class ChannelMonitor(Entity):
        """
        List of channel monitors, keyed by channel monitor name.
        
        .. attribute:: name  <key>
        
        	References the optical channel monitor name
        	**type**\:  str
        
        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Config>`
        
        .. attribute:: channels
        
        	Enclosing container for the list of values describing the power spectral density distribution
        	**type**\:   :py:class:`Channels <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Channels>`
        
        .. attribute:: config
        
        	Configuration data 
        	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Config>`
        
        .. attribute:: state
        
        	Operational state data 
        	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.State>`
        
        

        """

        _prefix = 'oc-chan-monitor'
        _revision = '2017-07-08'

        def __init__(self):
            super(ChannelMonitors.ChannelMonitor, self).__init__()

            self.yang_name = "channel-monitor"
            self.yang_parent_name = "channel-monitors"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"channels" : ("channels", ChannelMonitors.ChannelMonitor.Channels), "config" : ("config", ChannelMonitors.ChannelMonitor.Config), "state" : ("state", ChannelMonitors.ChannelMonitor.State)}
            self._child_list_classes = {}

            self.name = YLeaf(YType.str, "name")

            self.channels = ChannelMonitors.ChannelMonitor.Channels()
            self.channels.parent = self
            self._children_name_map["channels"] = "channels"
            self._children_yang_names.add("channels")

            self.config = ChannelMonitors.ChannelMonitor.Config()
            self.config.parent = self
            self._children_name_map["config"] = "config"
            self._children_yang_names.add("config")

            self.state = ChannelMonitors.ChannelMonitor.State()
            self.state.parent = self
            self._children_name_map["state"] = "state"
            self._children_yang_names.add("state")
            self._segment_path = lambda: "channel-monitor" + "[name='" + self.name.get() + "']"
            self._absolute_path = lambda: "openconfig-channel-monitor:channel-monitors/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(ChannelMonitors.ChannelMonitor, ['name'], name, value)


        class Channels(Entity):
            """
            Enclosing container for the list of values describing
            the power spectral density distribution
            
            .. attribute:: channel
            
            	List of tuples describing the PSD distribution
            	**type**\: list of    :py:class:`Channel <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Channels.Channel>`
            
            

            """

            _prefix = 'oc-chan-monitor'
            _revision = '2017-07-08'

            def __init__(self):
                super(ChannelMonitors.ChannelMonitor.Channels, self).__init__()

                self.yang_name = "channels"
                self.yang_parent_name = "channel-monitor"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"channel" : ("channel", ChannelMonitors.ChannelMonitor.Channels.Channel)}

                self.channel = YList(self)
                self._segment_path = lambda: "channels"

            def __setattr__(self, name, value):
                self._perform_setattr(ChannelMonitors.ChannelMonitor.Channels, [], name, value)


            class Channel(Entity):
                """
                List of tuples describing the PSD distribution
                
                .. attribute:: lower_frequency  <key>
                
                	Reference to the list key
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**refers to**\:  :py:class:`lower_frequency <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Channels.Channel.State>`
                
                .. attribute:: upper_frequency  <key>
                
                	Reference to the list key
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**refers to**\:  :py:class:`upper_frequency <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Channels.Channel.State>`
                
                .. attribute:: state
                
                	Operational state data for PSD
                	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_channel_monitor.ChannelMonitors.ChannelMonitor.Channels.Channel.State>`
                
                

                """

                _prefix = 'oc-chan-monitor'
                _revision = '2017-07-08'

                def __init__(self):
                    super(ChannelMonitors.ChannelMonitor.Channels.Channel, self).__init__()

                    self.yang_name = "channel"
                    self.yang_parent_name = "channels"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"state" : ("state", ChannelMonitors.ChannelMonitor.Channels.Channel.State)}
                    self._child_list_classes = {}

                    self.lower_frequency = YLeaf(YType.str, "lower-frequency")

                    self.upper_frequency = YLeaf(YType.str, "upper-frequency")

                    self.state = ChannelMonitors.ChannelMonitor.Channels.Channel.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")
                    self._segment_path = lambda: "channel" + "[lower-frequency='" + self.lower_frequency.get() + "']" + "[upper-frequency='" + self.upper_frequency.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(ChannelMonitors.ChannelMonitor.Channels.Channel, ['lower_frequency', 'upper_frequency'], name, value)


                class State(Entity):
                    """
                    Operational state data for PSD
                    
                    .. attribute:: lower_frequency
                    
                    	Lower frequency of the specified PSD
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: psd
                    
                    	Power spectral density expressed in nanowatts per megahertz, nW/MHz.  These units allow the value to often be greater than 1.0.  It also avoids dealing with zero values for 0dBm.  For example, a 40GHz wide channel with 0dBm power would be\:  0dBm = 1mW = 10^6nW  40GHz = 40,000MHz  0dBm/40GHz = 10^6nW/40,000MHz = 1000/40 = 25
                    	**type**\:  str
                    
                    	**length:** 32
                    
                    	**units**\: nW/MHz
                    
                    .. attribute:: upper_frequency
                    
                    	Upper frequency of the specified PSD
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'oc-chan-monitor'
                    _revision = '2017-07-08'

                    def __init__(self):
                        super(ChannelMonitors.ChannelMonitor.Channels.Channel.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.lower_frequency = YLeaf(YType.uint64, "lower-frequency")

                        self.psd = YLeaf(YType.str, "psd")

                        self.upper_frequency = YLeaf(YType.uint64, "upper-frequency")
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(ChannelMonitors.ChannelMonitor.Channels.Channel.State, ['lower_frequency', 'psd', 'upper_frequency'], name, value)


        class Config(Entity):
            """
            Configuration data 
            
            .. attribute:: monitor_port
            
            	Reference to system\-supplied name of the port that the channel monitor is physically connected to. This port will be of type MONITOR. This port is a tap off of the monitored\-port and would be in the same card as the monitored port. If this port is embedded in another card (i.e. an amplifier card) the device should still define a port representing the monitor port if it is internal and not physically present on the faceplate of the card
            	**type**\:  str
            
            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_platform.Components.Component>`
            
            .. attribute:: name
            
            	Reference to system\-supplied name of the port on the optical channel monitor (OCM). If this port is embedded in another card (i.e. an amplifier card) the device should still define a port representing the OCM even if it is internal and not physically present on the faceplate of the card
            	**type**\:  str
            
            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_platform.Components.Component>`
            
            

            """

            _prefix = 'oc-chan-monitor'
            _revision = '2017-07-08'

            def __init__(self):
                super(ChannelMonitors.ChannelMonitor.Config, self).__init__()

                self.yang_name = "config"
                self.yang_parent_name = "channel-monitor"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.monitor_port = YLeaf(YType.str, "monitor-port")

                self.name = YLeaf(YType.str, "name")
                self._segment_path = lambda: "config"

            def __setattr__(self, name, value):
                self._perform_setattr(ChannelMonitors.ChannelMonitor.Config, ['monitor_port', 'name'], name, value)


        class State(Entity):
            """
            Operational state data 
            
            .. attribute:: monitor_port
            
            	Reference to system\-supplied name of the port that the channel monitor is physically connected to. This port will be of type MONITOR. This port is a tap off of the monitored\-port and would be in the same card as the monitored port. If this port is embedded in another card (i.e. an amplifier card) the device should still define a port representing the monitor port if it is internal and not physically present on the faceplate of the card
            	**type**\:  str
            
            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_platform.Components.Component>`
            
            .. attribute:: name
            
            	Reference to system\-supplied name of the port on the optical channel monitor (OCM). If this port is embedded in another card (i.e. an amplifier card) the device should still define a port representing the OCM even if it is internal and not physically present on the faceplate of the card
            	**type**\:  str
            
            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_platform.Components.Component>`
            
            

            """

            _prefix = 'oc-chan-monitor'
            _revision = '2017-07-08'

            def __init__(self):
                super(ChannelMonitors.ChannelMonitor.State, self).__init__()

                self.yang_name = "state"
                self.yang_parent_name = "channel-monitor"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.monitor_port = YLeaf(YType.str, "monitor-port")

                self.name = YLeaf(YType.str, "name")
                self._segment_path = lambda: "state"

            def __setattr__(self, name, value):
                self._perform_setattr(ChannelMonitors.ChannelMonitor.State, ['monitor_port', 'name'], name, value)

    def clone_ptr(self):
        self._top_entity = ChannelMonitors()
        return self._top_entity




""" openconfig_mpls_types 

General types for MPLS / TE data model

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class MplsLabel(Enum):
    """
    MplsLabel

    type for MPLS label value encoding

    .. data:: IPV4_EXPLICIT_NULL = 0

    	valid at the bottom of the label stack,

    	indicates that stack must be popped and packet forwarded

    	based on IPv4 header

    .. data:: ROUTER_ALERT = 1

    	allowed anywhere in the label stack except

    	the bottom, local router delivers packet to the local CPU

    	when this label is at the top of the stack

    .. data:: IPV6_EXPLICIT_NULL = 2

    	valid at the bottom of the label stack,

    	indicates that stack must be popped and packet forwarded

    	based on IPv6 header

    .. data:: IMPLICIT_NULL = 3

    	assigned by local LSR but not carried in

    	packets

    .. data:: ENTROPY_LABEL_INDICATOR = 7

    	Entropy label indicator, to allow an LSR

    	to distinguish between entropy label and applicaiton

    	labels RFC 6790

    """

    IPV4_EXPLICIT_NULL = Enum.YLeaf(0, "IPV4_EXPLICIT_NULL")

    ROUTER_ALERT = Enum.YLeaf(1, "ROUTER_ALERT")

    IPV6_EXPLICIT_NULL = Enum.YLeaf(2, "IPV6_EXPLICIT_NULL")

    IMPLICIT_NULL = Enum.YLeaf(3, "IMPLICIT_NULL")

    ENTROPY_LABEL_INDICATOR = Enum.YLeaf(7, "ENTROPY_LABEL_INDICATOR")


class TunnelType(Enum):
    """
    TunnelType

    defines the tunnel type for the LSP

    .. data:: P2P = 0

    	point-to-point label-switched-path

    .. data:: P2MP = 1

    	point-to-multipoint label-switched-path

    .. data:: MP2MP = 2

    	multipoint-to-multipoint label-switched-path

    """

    P2P = Enum.YLeaf(0, "P2P")

    P2MP = Enum.YLeaf(1, "P2MP")

    MP2MP = Enum.YLeaf(2, "MP2MP")



class LspOperStatus(Identity):
    """
    Base identity for LSP operational status
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(LspOperStatus, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:lsp-oper-status")


class LspRole(Identity):
    """
    Base identity for describing the role of
    label switched path at the current node
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(LspRole, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:lsp-role")


class NullLabelType(Identity):
    """
    Base identity from which specific null\-label types are
    derived.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(NullLabelType, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:null-label-type")


class PathSetupProtocol(Identity):
    """
    base identity for supported MPLS signaling
    protocols
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(PathSetupProtocol, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:path-setup-protocol")


class ProtectionType(Identity):
    """
    base identity for protection type
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(ProtectionType, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:protection-type")


class TunnelAdminStatus(Identity):
    """
    Base identity for tunnel administrative status
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(TunnelAdminStatus, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:tunnel-admin-status")


class TunnelType(Identity):
    """
    Base identity from which specific tunnel types are
    derived.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(TunnelType, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:tunnel-type")


class ADMINDOWN(Identity):
    """
    LSP is administratively down
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(ADMINDOWN, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:ADMIN_DOWN")


class ADMINUP(Identity):
    """
    LSP is administratively up
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(ADMINUP, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:ADMIN_UP")


class DOWN(Identity):
    """
    LSP is operationally down or out of service
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(DOWN, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:DOWN")


class EGRESS(Identity):
    """
    Label switched path is an egress (tailend)
    LSP
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(EGRESS, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:EGRESS")


class EXPLICIT(Identity):
    """
    Explicit null label is used.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(EXPLICIT, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:EXPLICIT")


class IMPLICIT(Identity):
    """
    Implicit null label is used.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(IMPLICIT, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:IMPLICIT")


class INGRESS(Identity):
    """
    Label switched path is an ingress (headend)
    LSP
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(INGRESS, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:INGRESS")


class LinkNodeProtectionRequested(Identity):
    """
    node and link protection are both desired
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(LinkNodeProtectionRequested, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:link-node-protection-requested")


class LinkProtectionRequested(Identity):
    """
    link protection is desired
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(LinkProtectionRequested, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:link-protection-requested")


class P2MP(Identity):
    """
    TE point\-to\-multipoint tunnel type.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(P2MP, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:P2MP")


class P2P(Identity):
    """
    TE point\-to\-point tunnel type.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(P2P, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:P2P")


class PathSetupLdp(Identity):
    """
    LDP \- RFC 5036
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(PathSetupLdp, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:path-setup-ldp")


class PathSetupRsvp(Identity):
    """
    RSVP\-TE signaling protocol
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(PathSetupRsvp, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:path-setup-rsvp")


class PathSetupSr(Identity):
    """
    Segment routing
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(PathSetupSr, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:path-setup-sr")


class TRANSIT(Identity):
    """
    Label switched path is a transit LSP
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(TRANSIT, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:TRANSIT")


class UP(Identity):
    """
    LSP is operationally active and available
    for traffic.
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(UP, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:UP")


class Unprotected(Identity):
    """
    no protection is desired
    
    

    """

    _prefix = 'mplst'
    _revision = '2015-11-05'

    def __init__(self):
        super(Unprotected, self).__init__("http://openconfig.net/yang/mpls-types", "openconfig-mpls-types", "openconfig-mpls-types:unprotected")





#  ----------------------------------------------------------------
# Copyright 2016 Cisco Systems
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------


"""Setup for YDK


"""
from os import path
from setuptools import setup, find_packages

HERE = path.abspath(path.dirname(__file__))

INSTALL_REQUIREMENTS = ['ydk>=0.6.1']

NMSP_PKG_NAME = "ydk-models-openconfig"
NMSP_PKG_VERSION = "0.1.4"
NMSP_PKG_DEPENDENCIES = ['ydk-models-ietf>=0.1.3']


if NMSP_PKG_DEPENDENCIES != "$DEPENDENCY$":
    INSTALL_REQUIREMENTS.extend(NMSP_PKG_DEPENDENCIES)

NMSP_PACKAGES = ['ydk', 'ydk.models']
YDK_PACKAGES = find_packages(exclude=['contrib', 'docs*', 'tests*',
                                      'ncclient', 'samples'])


DESCRIPTION = "YDK bundle for OpenConfig models"
LONG_DESCRIPTION = "This YANG Development Kit (YDK) bundle provides APIs for OpenConfig YANG models. YDK facilitates the use of YANG data models by expressing the model semantics in an API and abstracting protocol/encoding details.  YDK is composed of a core package that defines services and providers, plus one or more module bundles.  This YDK bundle for OpenConfig models uses the YDK core package and additional model bundles.  You can find the SDK documentation at http://ydk.cisco.com/py/docs  You can find more details on YDK at http://ydk.io"

setup(
    name=NMSP_PKG_NAME,
    version=NMSP_PKG_VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    url='https://github.com/CiscoDevNet/ydk-py',
    author='Cisco Systems',
    author_email='yang-dk@cisco.com',
    license='Apache 2.0',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',
        'Intended Audience :: System Administrators',
        'Topic :: Software Development :: Build Tools',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: C++'
    ],
    keywords='yang, C++11, python bindings',
    packages=YDK_PACKAGES,
    namespace_packages=NMSP_PACKAGES,
    install_requires=INSTALL_REQUIREMENTS,
    include_package_data=True
)



""" openconfig_lacp 

This module describes configuration and operational state
data for Link Aggregation Control Protocol (LACP) for
managing aggregate interfaces.   It works in conjunction with
the OpenConfig interfaces and aggregate interfaces models.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class LacpActivityType(Enum):
    """
    LacpActivityType

    Describes the LACP membership type, active or passive, of the

    interface in the aggregate

    .. data:: ACTIVE = 0

    	Interface is an active member, i.e., will detect and

    	maintain aggregates

    .. data:: PASSIVE = 1

    	Interface is a passive member, i.e., it participates

    	with an active partner

    """

    ACTIVE = Enum.YLeaf(0, "ACTIVE")

    PASSIVE = Enum.YLeaf(1, "PASSIVE")


class LacpPeriodType(Enum):
    """
    LacpPeriodType

    Defines the period options for the time between sending

    LACP messages

    .. data:: FAST = 0

    	Send LACP packets every second

    .. data:: SLOW = 1

    	Send LACP packets every 30 seconds

    """

    FAST = Enum.YLeaf(0, "FAST")

    SLOW = Enum.YLeaf(1, "SLOW")


class LacpSynchronizationType(Enum):
    """
    LacpSynchronizationType

    Indicates LACP synchronization state of participant

    .. data:: IN_SYNC = 0

    	Participant is in sync with the system id and key

    	transmitted

    .. data:: OUT_SYNC = 1

    	Participant is not in sync with the system id and key

    	transmitted

    """

    IN_SYNC = Enum.YLeaf(0, "IN_SYNC")

    OUT_SYNC = Enum.YLeaf(1, "OUT_SYNC")


class LacpTimeoutType(Enum):
    """
    LacpTimeoutType

    Type of timeout used, short or long, by LACP participants

    .. data:: LONG = 0

    	Participant wishes to use long timeouts to detect

    	status of the aggregate, i.e., will expect less frequent

    	transmissions. Long timeout is 90 seconds.

    .. data:: SHORT = 1

    	Participant wishes to use short timeouts, i.e., expects

    	frequent transmissions to aggressively detect status

    	changes. Short timeout is 3 seconds.

    """

    LONG = Enum.YLeaf(0, "LONG")

    SHORT = Enum.YLeaf(1, "SHORT")



class Lacp(Entity):
    """
    Configuration and operational state data for LACP protocol
    operation on the aggregate interface
    
    .. attribute:: config
    
    	Configuration data for LACP
    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_lacp.Lacp.Config>`
    
    .. attribute:: interfaces
    
    	Enclosing container for the list of LACP\-enabled interfaces
    	**type**\:   :py:class:`Interfaces <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces>`
    
    .. attribute:: state
    
    	Operational state data for LACP
    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_lacp.Lacp.State>`
    
    

    """

    _prefix = 'oc-lacp'
    _revision = '2016-05-26'

    def __init__(self):
        super(Lacp, self).__init__()
        self._top_entity = None

        self.yang_name = "lacp"
        self.yang_parent_name = "openconfig-lacp"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"config" : ("config", Lacp.Config), "interfaces" : ("interfaces", Lacp.Interfaces), "state" : ("state", Lacp.State)}
        self._child_list_classes = {}

        self.config = Lacp.Config()
        self.config.parent = self
        self._children_name_map["config"] = "config"
        self._children_yang_names.add("config")

        self.interfaces = Lacp.Interfaces()
        self.interfaces.parent = self
        self._children_name_map["interfaces"] = "interfaces"
        self._children_yang_names.add("interfaces")

        self.state = Lacp.State()
        self.state.parent = self
        self._children_name_map["state"] = "state"
        self._children_yang_names.add("state")
        self._segment_path = lambda: "openconfig-lacp:lacp"


    class Config(Entity):
        """
        Configuration data for LACP
        
        .. attribute:: system_priority
        
        	Sytem priority used by the node on this LAG interface. Lower value is higher priority for determining which node is the controlling system
        	**type**\:  int
        
        	**range:** 0..65535
        
        

        """

        _prefix = 'oc-lacp'
        _revision = '2016-05-26'

        def __init__(self):
            super(Lacp.Config, self).__init__()

            self.yang_name = "config"
            self.yang_parent_name = "lacp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.system_priority = YLeaf(YType.uint16, "system-priority")
            self._segment_path = lambda: "config"
            self._absolute_path = lambda: "openconfig-lacp:lacp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Lacp.Config, ['system_priority'], name, value)


    class Interfaces(Entity):
        """
        Enclosing container for the list of LACP\-enabled
        interfaces
        
        .. attribute:: interface
        
        	List of aggregate interfaces managed by LACP
        	**type**\: list of    :py:class:`Interface <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface>`
        
        

        """

        _prefix = 'oc-lacp'
        _revision = '2016-05-26'

        def __init__(self):
            super(Lacp.Interfaces, self).__init__()

            self.yang_name = "interfaces"
            self.yang_parent_name = "lacp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"interface" : ("interface", Lacp.Interfaces.Interface)}

            self.interface = YList(self)
            self._segment_path = lambda: "interfaces"
            self._absolute_path = lambda: "openconfig-lacp:lacp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Lacp.Interfaces, [], name, value)


        class Interface(Entity):
            """
            List of aggregate interfaces managed by LACP
            
            .. attribute:: name  <key>
            
            	Reference to the list key
            	**type**\:  str
            
            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Config>`
            
            .. attribute:: config
            
            	Configuration data for each LACP aggregate interface
            	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Config>`
            
            .. attribute:: members
            
            	Enclosing container for the list of members interfaces of the aggregate. This list is considered operational state only so is labeled config false and has no config container
            	**type**\:   :py:class:`Members <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Members>`
            
            .. attribute:: state
            
            	Operational state data for each LACP aggregate interface
            	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.State>`
            
            

            """

            _prefix = 'oc-lacp'
            _revision = '2016-05-26'

            def __init__(self):
                super(Lacp.Interfaces.Interface, self).__init__()

                self.yang_name = "interface"
                self.yang_parent_name = "interfaces"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"config" : ("config", Lacp.Interfaces.Interface.Config), "members" : ("members", Lacp.Interfaces.Interface.Members), "state" : ("state", Lacp.Interfaces.Interface.State)}
                self._child_list_classes = {}

                self.name = YLeaf(YType.str, "name")

                self.config = Lacp.Interfaces.Interface.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"
                self._children_yang_names.add("config")

                self.members = Lacp.Interfaces.Interface.Members()
                self.members.parent = self
                self._children_name_map["members"] = "members"
                self._children_yang_names.add("members")

                self.state = Lacp.Interfaces.Interface.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"
                self._children_yang_names.add("state")
                self._segment_path = lambda: "interface" + "[name='" + self.name.get() + "']"
                self._absolute_path = lambda: "openconfig-lacp:lacp/interfaces/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Lacp.Interfaces.Interface, ['name'], name, value)


            class Config(Entity):
                """
                Configuration data for each LACP aggregate interface
                
                .. attribute:: interval
                
                	Set the period between LACP messages \-\- uses the lacp\-period\-type enumeration
                	**type**\:   :py:class:`LacpPeriodType <ydk.models.openconfig.openconfig_lacp.LacpPeriodType>`
                
                	**default value**\: SLOW
                
                .. attribute:: lacp_mode
                
                	ACTIVE is to initiate the transmission of LACP packets. PASSIVE is to wait for peer to initiate the transmission of LACP packets
                	**type**\:   :py:class:`LacpActivityType <ydk.models.openconfig.openconfig_lacp.LacpActivityType>`
                
                	**default value**\: ACTIVE
                
                .. attribute:: name
                
                	Reference to the interface on which LACP should be configured.   The type of the target interface must be ieee8023adLag
                	**type**\:  str
                
                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                
                .. attribute:: system_id_mac
                
                	The MAC address portion of the node's System ID. This is combined with the system priority to construct the 8\-octet system\-id
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: system_priority
                
                	Sytem priority used by the node on this LAG interface. Lower value is higher priority for determining which node is the controlling system
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'oc-lacp'
                _revision = '2016-05-26'

                def __init__(self):
                    super(Lacp.Interfaces.Interface.Config, self).__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interval = YLeaf(YType.enumeration, "interval")

                    self.lacp_mode = YLeaf(YType.enumeration, "lacp-mode")

                    self.name = YLeaf(YType.str, "name")

                    self.system_id_mac = YLeaf(YType.str, "system-id-mac")

                    self.system_priority = YLeaf(YType.uint16, "system-priority")
                    self._segment_path = lambda: "config"

                def __setattr__(self, name, value):
                    self._perform_setattr(Lacp.Interfaces.Interface.Config, ['interval', 'lacp_mode', 'name', 'system_id_mac', 'system_priority'], name, value)


            class Members(Entity):
                """
                Enclosing container for the list of members interfaces of
                the aggregate. This list is considered operational state
                only so is labeled config false and has no config container
                
                .. attribute:: member
                
                	List of member interfaces and their associated status for a LACP\-controlled aggregate interface.  Member list is not configurable here \-\- each interface indicates items its participation in the LAG
                	**type**\: list of    :py:class:`Member <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Members.Member>`
                
                

                """

                _prefix = 'oc-lacp'
                _revision = '2016-05-26'

                def __init__(self):
                    super(Lacp.Interfaces.Interface.Members, self).__init__()

                    self.yang_name = "members"
                    self.yang_parent_name = "interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"member" : ("member", Lacp.Interfaces.Interface.Members.Member)}

                    self.member = YList(self)
                    self._segment_path = lambda: "members"

                def __setattr__(self, name, value):
                    self._perform_setattr(Lacp.Interfaces.Interface.Members, [], name, value)


                class Member(Entity):
                    """
                    List of member interfaces and their associated status for
                    a LACP\-controlled aggregate interface.  Member list is not
                    configurable here \-\- each interface indicates items
                    its participation in the LAG.
                    
                    .. attribute:: interface  <key>
                    
                    	Reference to aggregate member interface
                    	**type**\:  str
                    
                    	**refers to**\:  :py:class:`interface <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Members.Member.State>`
                    
                    .. attribute:: state
                    
                    	Operational state data for aggregate members
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Members.Member.State>`
                    
                    

                    """

                    _prefix = 'oc-lacp'
                    _revision = '2016-05-26'

                    def __init__(self):
                        super(Lacp.Interfaces.Interface.Members.Member, self).__init__()

                        self.yang_name = "member"
                        self.yang_parent_name = "members"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"state" : ("state", Lacp.Interfaces.Interface.Members.Member.State)}
                        self._child_list_classes = {}

                        self.interface = YLeaf(YType.str, "interface")

                        self.state = Lacp.Interfaces.Interface.Members.Member.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "member" + "[interface='" + self.interface.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Lacp.Interfaces.Interface.Members.Member, ['interface'], name, value)


                    class State(Entity):
                        """
                        Operational state data for aggregate members
                        
                        .. attribute:: activity
                        
                        	Indicates participant is active or passive
                        	**type**\:   :py:class:`LacpActivityType <ydk.models.openconfig.openconfig_lacp.LacpActivityType>`
                        
                        .. attribute:: aggregatable
                        
                        	A true value indicates that the participant will allow the link to be used as part of the aggregate. A false value indicates the link should be used as an individual link
                        	**type**\:  bool
                        
                        .. attribute:: collecting
                        
                        	If true, the participant is collecting incoming frames on the link, otherwise false
                        	**type**\:  bool
                        
                        .. attribute:: counters
                        
                        	LACP protocol counters
                        	**type**\:   :py:class:`Counters <ydk.models.openconfig.openconfig_lacp.Lacp.Interfaces.Interface.Members.Member.State.Counters>`
                        
                        .. attribute:: distributing
                        
                        	When true, the participant is distributing outgoing frames; when false, distribution is disabled
                        	**type**\:  bool
                        
                        .. attribute:: interface
                        
                        	Reference to interface member of the LACP aggregate
                        	**type**\:  str
                        
                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                        
                        .. attribute:: oper_key
                        
                        	Current operational value of the key for the aggregate interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_id
                        
                        	MAC address representing the protocol partner's interface system ID
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: partner_key
                        
                        	Operational value of the protocol partner's key
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: synchronization
                        
                        	Indicates whether the participant is in\-sync or out\-of\-sync
                        	**type**\:   :py:class:`LacpSynchronizationType <ydk.models.openconfig.openconfig_lacp.LacpSynchronizationType>`
                        
                        .. attribute:: system_id
                        
                        	MAC address that defines the local system ID for the aggregate interface
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: timeout
                        
                        	The timeout type (short or long) used by the participant
                        	**type**\:   :py:class:`LacpTimeoutType <ydk.models.openconfig.openconfig_lacp.LacpTimeoutType>`
                        
                        

                        """

                        _prefix = 'oc-lacp'
                        _revision = '2016-05-26'

                        def __init__(self):
                            super(Lacp.Interfaces.Interface.Members.Member.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "member"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"counters" : ("counters", Lacp.Interfaces.Interface.Members.Member.State.Counters)}
                            self._child_list_classes = {}

                            self.activity = YLeaf(YType.enumeration, "activity")

                            self.aggregatable = YLeaf(YType.boolean, "aggregatable")

                            self.collecting = YLeaf(YType.boolean, "collecting")

                            self.distributing = YLeaf(YType.boolean, "distributing")

                            self.interface = YLeaf(YType.str, "interface")

                            self.oper_key = YLeaf(YType.uint16, "oper-key")

                            self.partner_id = YLeaf(YType.str, "partner-id")

                            self.partner_key = YLeaf(YType.uint16, "partner-key")

                            self.synchronization = YLeaf(YType.enumeration, "synchronization")

                            self.system_id = YLeaf(YType.str, "system-id")

                            self.timeout = YLeaf(YType.enumeration, "timeout")

                            self.counters = Lacp.Interfaces.Interface.Members.Member.State.Counters()
                            self.counters.parent = self
                            self._children_name_map["counters"] = "counters"
                            self._children_yang_names.add("counters")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Lacp.Interfaces.Interface.Members.Member.State, ['activity', 'aggregatable', 'collecting', 'distributing', 'interface', 'oper_key', 'partner_id', 'partner_key', 'synchronization', 'system_id', 'timeout'], name, value)


                        class Counters(Entity):
                            """
                            LACP protocol counters
                            
                            .. attribute:: lacp_errors
                            
                            	Number of LACPDU illegal packet errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: lacp_in_pkts
                            
                            	Number of LACPDUs received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: lacp_out_pkts
                            
                            	Number of LACPDUs transmitted
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: lacp_rx_errors
                            
                            	Number of LACPDU receive packet errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: lacp_tx_errors
                            
                            	Number of LACPDU transmit packet errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: lacp_unknown_errors
                            
                            	Number of LACPDU unknown packet errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'oc-lacp'
                            _revision = '2016-05-26'

                            def __init__(self):
                                super(Lacp.Interfaces.Interface.Members.Member.State.Counters, self).__init__()

                                self.yang_name = "counters"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.lacp_errors = YLeaf(YType.uint64, "lacp-errors")

                                self.lacp_in_pkts = YLeaf(YType.uint64, "lacp-in-pkts")

                                self.lacp_out_pkts = YLeaf(YType.uint64, "lacp-out-pkts")

                                self.lacp_rx_errors = YLeaf(YType.uint64, "lacp-rx-errors")

                                self.lacp_tx_errors = YLeaf(YType.uint64, "lacp-tx-errors")

                                self.lacp_unknown_errors = YLeaf(YType.uint64, "lacp-unknown-errors")
                                self._segment_path = lambda: "counters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Lacp.Interfaces.Interface.Members.Member.State.Counters, ['lacp_errors', 'lacp_in_pkts', 'lacp_out_pkts', 'lacp_rx_errors', 'lacp_tx_errors', 'lacp_unknown_errors'], name, value)


            class State(Entity):
                """
                Operational state data for each LACP aggregate
                interface
                
                .. attribute:: interval
                
                	Set the period between LACP messages \-\- uses the lacp\-period\-type enumeration
                	**type**\:   :py:class:`LacpPeriodType <ydk.models.openconfig.openconfig_lacp.LacpPeriodType>`
                
                	**default value**\: SLOW
                
                .. attribute:: lacp_mode
                
                	ACTIVE is to initiate the transmission of LACP packets. PASSIVE is to wait for peer to initiate the transmission of LACP packets
                	**type**\:   :py:class:`LacpActivityType <ydk.models.openconfig.openconfig_lacp.LacpActivityType>`
                
                	**default value**\: ACTIVE
                
                .. attribute:: name
                
                	Reference to the interface on which LACP should be configured.   The type of the target interface must be ieee8023adLag
                	**type**\:  str
                
                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                
                .. attribute:: system_id_mac
                
                	The MAC address portion of the node's System ID. This is combined with the system priority to construct the 8\-octet system\-id
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: system_priority
                
                	Sytem priority used by the node on this LAG interface. Lower value is higher priority for determining which node is the controlling system
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'oc-lacp'
                _revision = '2016-05-26'

                def __init__(self):
                    super(Lacp.Interfaces.Interface.State, self).__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interval = YLeaf(YType.enumeration, "interval")

                    self.lacp_mode = YLeaf(YType.enumeration, "lacp-mode")

                    self.name = YLeaf(YType.str, "name")

                    self.system_id_mac = YLeaf(YType.str, "system-id-mac")

                    self.system_priority = YLeaf(YType.uint16, "system-priority")
                    self._segment_path = lambda: "state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Lacp.Interfaces.Interface.State, ['interval', 'lacp_mode', 'name', 'system_id_mac', 'system_priority'], name, value)


    class State(Entity):
        """
        Operational state data for LACP
        
        .. attribute:: system_priority
        
        	Sytem priority used by the node on this LAG interface. Lower value is higher priority for determining which node is the controlling system
        	**type**\:  int
        
        	**range:** 0..65535
        
        

        """

        _prefix = 'oc-lacp'
        _revision = '2016-05-26'

        def __init__(self):
            super(Lacp.State, self).__init__()

            self.yang_name = "state"
            self.yang_parent_name = "lacp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.system_priority = YLeaf(YType.uint16, "system-priority")
            self._segment_path = lambda: "state"
            self._absolute_path = lambda: "openconfig-lacp:lacp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Lacp.State, ['system_priority'], name, value)

    def clone_ptr(self):
        self._top_entity = Lacp()
        return self._top_entity




""" openconfig_if_ip 

Model for managing IP interfaces.

This model reuses most of the IETF YANG model for IP management
described by RFC 7277.  The primary differences are in the
structure of configuration and state data.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class IpAddressOrigin(Enum):
    """
    IpAddressOrigin

    The origin of an address.

    .. data:: OTHER = 0

    	None of the following.

    .. data:: STATIC = 1

    	Indicates that the address has been statically

    	configured - for example, using NETCONF or a Command Line

    	Interface.

    .. data:: DHCP = 2

    	Indicates an address that has been assigned to this

    	system by a DHCP server.

    .. data:: LINK_LAYER = 3

    	Indicates an address created by IPv6 stateless

    	autoconfiguration that embeds a link-layer address in its

    	interface identifier.

    .. data:: RANDOM = 4

    	[adapted from RFC 7277]

    	Indicates an address chosen by the system at

    	random, e.g., an IPv4 address within 169.254/16, an

    	RFC 4941 temporary address, or an RFC 7217 semantically

    	opaque address.

    """

    OTHER = Enum.YLeaf(0, "OTHER")

    STATIC = Enum.YLeaf(1, "STATIC")

    DHCP = Enum.YLeaf(2, "DHCP")

    LINK_LAYER = Enum.YLeaf(3, "LINK_LAYER")

    RANDOM = Enum.YLeaf(4, "RANDOM")


class NeighborOrigin(Enum):
    """
    NeighborOrigin

    The origin of a neighbor entry.

    .. data:: OTHER = 0

    	None of the following.

    .. data:: STATIC = 1

    	Indicates that the mapping has been statically

    	configured - for example, using NETCONF or a Command Line

    	Interface.

    .. data:: DYNAMIC = 2

    	[adapted from RFC 7277]

    	Indicates that the mapping has been dynamically resolved

    	using, e.g., IPv4 ARP or the IPv6 Neighbor Discovery

    	protocol.

    """

    OTHER = Enum.YLeaf(0, "OTHER")

    STATIC = Enum.YLeaf(1, "STATIC")

    DYNAMIC = Enum.YLeaf(2, "DYNAMIC")



